@@ -7,14 +7,16 @@ from ..registry_tools import iso_register
 class Belarus(OrthodoxCalendar):
     'Belarus'
     "as of http://president.gov.by/en/holidays_en/"
+    # Civil holidays
+    include_labour_day = True
 
+    # Christian holidays
     include_christmas = False
 
     FIXED_HOLIDAYS = OrthodoxCalendar.FIXED_HOLIDAYS + (
         (1, 2, "Day After New Year"),
         (1, 7, "Christmas (Orthodox)"),
         (3, 8, "International Women's Day"),
-        (5, 1, "Labour Day"),
         (5, 9, "Victory Day"),
         (7, 3, "Republic Day"),
         (11, 7, "October Revolution Day"),
