@@ -5,8 +5,7 @@ from ..europe import (
     # FranceAlsaceMoselle,  # TODO: Should we add it to the registry?
     Greece, Hungary, Iceland, Ireland, Italy, Latvia, Lithuania, Luxembourg,
     Malta, Monaco, Netherlands, Norway, Poland, Portugal, Romania, Russia,
-    Slovakia, Slovenia, Spain,
-    # Catalonia,  # TODO: Add it to registry
+    Slovakia, Slovenia, Spain, Catalonia,
     Sweden, UnitedKingdom,
     UnitedKingdomNorthernIreland,
 )
@@ -47,6 +46,10 @@ SWITZERLAND_REGION_CLASSES = (
     Ticino, Uri, Vaud, Valais, Zug, Zurich
 )
 
+SPAIN_REGION_CLASSES = (
+    Catalonia,
+)
+
 
 class RegistryEurope(TestCase):
     def test_europe(self):
@@ -91,21 +94,30 @@ class RegistryEurope(TestCase):
             self.assertIn(klass, classes)
         for klass in SWITZERLAND_REGION_CLASSES:
             self.assertIn(klass, classes)
+        for klass in SPAIN_REGION_CLASSES:
+            self.assertIn(klass, classes)
 
-    def test_germany_subregion(self):
+    def test_germany_subregions(self):
         # Get all the subregions
         classes = (v for k, v in registry.get_subregions('DE').items())
         classes = list(classes)
         for klass in GERMANY_REGION_CLASSES:
             self.assertIn(klass, classes)
 
-    def test_switzerland_subregion(self):
+    def test_switzerland_subregions(self):
         # Get all the subregions
         classes = (v for k, v in registry.get_subregions('CH').items())
         classes = list(classes)
         for klass in SWITZERLAND_REGION_CLASSES:
             self.assertIn(klass, classes)
 
+    def test_spain_subregions(self):
+        # Get all the subregions
+        classes = (v for k, v in registry.get_subregions('ES').items())
+        classes = list(classes)
+        for klass in SPAIN_REGION_CLASSES:
+            self.assertIn(klass, classes)
+
     def test_slovenia_code(self):
         # Source: https://github.com/peopledoc/workalendar/pull/291
         self.assertEqual(registry.region_registry['SI'], Slovenia)
